#!/usr/bin/env python
__all__=["cmds","displayops","einit","epprocess"]
from . import cmds 
from . import displayops 
from . import einit 
from . import epprocess

__name__='essential-pathway'
__version__ = '1.0'
__short_description__ = 'Manage your most commonly used directories in command line, requires the tcl edition Environment Module.'
__author__ = 'realasking'
__author_email__ ='<realasking@gmail.com,tomwangsim@163.com>'
__license__ = 'LGPLv3'
